# -*- coding: utf-8 -*-

"""
firstapicalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OperationTypeEnum(object):

    """Implementation of the 'Operation Type' enum.

    Type of the operation

    Attributes:
        SUM: addition
        SUBTRACT: subtration
        MULTIPLY: multiplication
        DIVIDE: division

    """

    SUM = 'SUM'

    SUBTRACT = 'SUBTRACT'

    MULTIPLY = 'MULTIPLY'

    DIVIDE = 'DIVIDE'
